/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.car.settings.security;

import static com.google.common.truth.Truth.assertThat;

import static org.mockito.Mockito.verify;

import com.android.car.settings.testutils.BaseTestActivity;
import com.android.car.settings.testutils.DialogTestUtils;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.robolectric.Robolectric;
import org.robolectric.RobolectricTestRunner;

@RunWith(RobolectricTestRunner.class)
public class ConfirmRemoveScreenLockDialogTest {

    private static final String TEST_TAG = "test_dialog_tag";

    private BaseTestActivity mTestActivity;
    private ConfirmRemoveScreenLockDialog mDialog;
    @Mock
    private ConfirmRemoveScreenLockDialog.ConfirmRemoveScreenLockListener mListener;

    @Before
    public void setUp() {
        MockitoAnnotations.initMocks(this);
        mDialog = new ConfirmRemoveScreenLockDialog();
        mDialog.setConfirmRemoveScreenLockListener(mListener);
        mTestActivity = Robolectric.setupActivity(BaseTestActivity.class);
        mDialog.show(mTestActivity.getSupportFragmentManager(), TEST_TAG);
    }

    @Test
    public void testInitialState_dialogShown() {
        assertThat(isDialogShown()).isTrue();
    }

    @Test
    public void testConfirmRemoveScreenLockListenerCalled_listenerCalled() {
        DialogTestUtils.clickPositiveButton(mDialog);
        verify(mListener).onConfirmRemoveScreenLock();
    }

    @Test
    public void testConfirmRemoveScreenLockListenerCalled_dialogDismissed() {
        DialogTestUtils.clickPositiveButton(mDialog);
        assertThat(isDialogShown()).isFalse();
    }

    private boolean isDialogShown() {
        return mTestActivity.getSupportFragmentManager().findFragmentByTag(TEST_TAG) != null;
    }
}
